import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./stateful-trainings.stories";

<Meta of={ComponentStories} name="Docs" />

# StatefulTrainings

The `<ux-iws-stateful-trainings>` component renders a list of `<ux-accordion>` items, grouped by category.
The component retrieves the data from the related `ContentDataProvider`.

<Canvas of={ComponentStories.Default}></Canvas>

## With Filter

The `<ux-iws-stateful-trainings>` is connected to the related `<ux-iws-stateful-filter>` with the same `scope`.

<Canvas of={ComponentStories.WithFilter}></Canvas>

## Content API

### Interface

```typescript
export interface TrainingItem extends Record<string, any> {
    title: string;
    id: number;
    category: number | string;
    type: string;
    typeId: number;
    level: string;
    languages: string[];
    description: string;
    events: TrainingEvent[];
    details: TrainingDetails;
}

export interface DownloadSchema extends ContentDataSchema {
    category: {
        trainingType: Array<number | string>;
    };
}
```

### Content Translations

All required translations for content data labels and values must be passed as JSON string or object to the
`<ux-iws-stateful-trainings>` component via the `translations` prop.

**Example Content Translations:**

```json
{
    "category": {
        "values": {
            "1001": "Betriebsanleitungen",
            "1004": "Software-Handbücher & Programmieranleitungen"
        }
    },
    "date": {
        "label": "Ausgabedatum"
    },
    "languages": {
        "label": "Sprachen",
        "values": {
            "en": "English",
            "de": "Deutsch",
            "fr": "Français",
            "it": "Italiano"
        }
    },
    "size": {
        "label": "Dateigröße"
    },
    "cta": {
        "label": "Download"
    }
}
```

## Filter API

The component is connected to any `<ux-iws-stateful-filter>` component with the same `scope`.

```json
{
    "filterBlocks": [
        {
            "type": "select",
            "multiple": false,
            "name": "language",
            "options": [
                {
                    "value": "en",
                    "selected": false
                },
                {
                    "value": "de",
                    "selected": false
                }
            ]
        },
        {
            "type": "checkbox",
            "filterItems": [
                {
                    "name": "equipment-material",
                    "value": "equipment-material",
                    "active": false
                }
            ]
        }
    ]
}
```

### Filter Translations

The required translations for filter labels must be passed as JSON string or object to the
`<ux-iws-stateful-filter>` component via the `translations` prop.

**Example Filter Translations:**

```json
{
    "language": {
        "placeholder": "All languages",
        "values": {
            "en": "English",
            "de": "Deutsch",
            "fr": "Français",
            "it": "Italiano"
        }
    },
    "equipment-material": {
        "label": "Show sub-equipment documents"
    }
}
```

## Developer Documentation

<Controls />
